
import React, { useState, useEffect } from 'react';
import { BrowserRouter as Router, Route, Routes, Navigate, useLocation } from 'react-router-dom';
import { Toaster } from "sonner";
import Index from './pages/Index';
import SignIn from './pages/auth/SignIn';
import SignUp from './pages/auth/SignUp';
import VerifyOTP from './pages/auth/VerifyOTP';
import PredictionForm from './pages/PredictionForm';
import ResultsDashboard from './pages/ResultsDashboard';
import NotFound from './pages/NotFound';
import DatasetModel from './pages/DatasetModel';
import { useAuth } from './contexts/AuthContext';

// Protected route component
const ProtectedRoute = ({ children }: { children: React.ReactNode }) => {
  const { isAuthenticated, isLoading } = useAuth();
  const location = useLocation();

  useEffect(() => {
    // Scroll to top on route change
    window.scrollTo(0, 0);
  }, [location.pathname]);

  if (isLoading) {
    return <div className="flex items-center justify-center h-screen">Loading...</div>;
  }

  if (!isAuthenticated) {
    // Pass the current location to the sign-in page, so we can redirect back after authentication
    return <Navigate to="/sign-in" state={{ from: location }} replace />;
  }

  return <>{children}</>;
};

// Auth route - redirects to assessment if user is already authenticated
const AuthRoute = ({ children }: { children: React.ReactNode }) => {
  const { isAuthenticated, isLoading } = useAuth();
  const location = useLocation();
  
  // Get the redirect path from location state or default to /assessment
  const from = location.state?.from?.pathname || '/assessment';

  if (isLoading) {
    return <div className="flex items-center justify-center h-screen">Loading...</div>;
  }

  if (isAuthenticated) {
    return <Navigate to={from} replace />;
  }

  return <>{children}</>;
};

function App() {
  const [isSSR, setIsSSR] = useState(true);

  useEffect(() => {
    setIsSSR(false);
  }, []);

  return (
    <Router>
      <Routes>
        <Route path="/" element={<Index />} />
        
        {/* Auth routes - redirect to assessment if already logged in */}
        <Route path="/sign-in" element={
          <AuthRoute>
            <SignIn />
          </AuthRoute>
        } />
        <Route path="/sign-up" element={
          <AuthRoute>
            <SignUp />
          </AuthRoute>
        } />
        <Route path="/verify-otp" element={
          <AuthRoute>
            <VerifyOTP />
          </AuthRoute>
        } />
        
        {/* Protected routes - require authentication */}
        <Route path="/assessment" element={
          <ProtectedRoute>
            <PredictionForm />
          </ProtectedRoute>
        } />
        <Route path="/results" element={
          <ProtectedRoute>
            <ResultsDashboard />
          </ProtectedRoute>
        } />
        
        {/* Dataset Model route kept but only accessible by direct URL for developers */}
        <Route path="/dataset-model" element={
          <ProtectedRoute>
            <DatasetModel />
          </ProtectedRoute>
        } />
        
        {/* For backward compatibility, add a redirect from /prediction to /assessment */}
        <Route path="/prediction" element={<Navigate to="/assessment" replace />} />
        
        <Route path="*" element={<NotFound />} />
      </Routes>
      <Toaster position="top-center" richColors />
    </Router>
  );
}

export default App;
